@@ -33,6 +33,25 @@ class CheckSAM
         }
         return array(-1,-1,0);
     }
+
+    public static function decryptPass($encryptedpasswd, &$passwd)
+    {
+        $cmd = new Epygi\Shell\Command(self::BIN_SAMSON);
+        $cmd->arg('-de');
+        $cmd->arg($encryptedpasswd);
+
+        // run
+        try {
+            if ($cmd->execute() == 0) {
+		$passwd = $cmd->data[0];
+                return 0;
+            }
+        }
+        catch(\Exception $e) {
+
+        }
+        return -1;
+    }
     
     public static function samGet2faKey($user)
     {
